{ pkgs, config, ... }:

{
  home.packages = with pkgs; [
    lsd
    bat
    fd
    ripgrep
    fzf
    tmux
    fastfetch
    tre-command
    btop
    zsh-completions
    nix-zsh-completions
    git
  ];

  programs.bat = {
    enable = true;
    config = {
      theme = "ansi";
    };
  };

  programs.btop = {
    enable = true;
    settings = {
      color_theme = "TTY";
    };
  };

  home.file.".zshenv".enable = false;
  home.file.".config/zsh/conf.d" = {
    source = ./conf.d;
    recursive = true;
  };
  programs.zsh = {
    enable = true;
    enableCompletion = true;
    autosuggestion.enable = true;
    syntaxHighlighting.enable = true;
    dotDir = ".config/zsh";
    autocd = true;

    history.size = 10000;
    history.ignoreAllDups = true;
    /* Not persisted on purpose */
    history.path = "${config.xdg.cacheHome}/zsh_history";

    shellAliases = {
      cat = "bat --paging=never --wrap=never --style='changes,snip,numbers'";
      ls = "lsd";
      tree = "tre";
    };

    initExtra = ''
      alias -g -- -h='-h 2>&1 | bat --language=help --style=plain'
      alias -g -- --help='--help 2>&1 | bat --language=help --style=plain'

      #for dotfile in "$ZDOTDIR/conf.d/"*; do
      #  source "$dotfile"
      #done

      local c0=$'%{\e[0m%}'
      local c31=$'%{\e[31m%}'
      local c33=$'%{\e[33m%}'
      local c34=$'%{\e[34m%}'
      local c35=$'%{\e[35m%}'
      local c38=$'%{\e[38m%}'

      local nix_shell_ps1_t=" $c34{$c33󱄅 shell$c34}$c0"
      local path_no_ghostty="$(echo "$PATH" | sed -e 's/:\/nix\/store\/.*-ghostty-.*\/bin://g')"
      if [ -n "$IN_NIX_SHELL" ]; then
          local nix_shell_ps1="$nix_shell_ps1_t"
      elif [[ "$path_no_ghostty" == *"/nix/store"* ]]; then
          IN_NIX_SHELL=true
          local nix_shell_ps1="$nix_shell_ps1_t"
      fi

      setopt prompt_subst
      autoload -Uz vcs_info
      zstyle ':vcs_info:*' enable git
      zstyle ':vcs_info:*' formats " ''${c34}''${c0}''${c31}(%b)''${c0}"
      precmd () { vcs_info }

      export PS1="''${c38}[''${c35}%3~''${c0}''${vcs_info_msg_0_}''${nix_shell_ps1}''${c38}]''${c0}# "
    '';

    plugins = [
      {
        name = "zsh-nix-shell";
        file = "nix-shell.plugin.zsh";
        src = pkgs.fetchFromGitHub {
          owner = "chisui";
          repo = "zsh-nix-shell";
          rev = "v0.8.0";
          sha256 = "1lzrn0n4fxfcgg65v0qhnj7wnybybqzs4adz7xsrkgmcsr0ii8b7";
        };
      }
    ];
  };
}
